@@ -6,7 +6,7 @@ from zygoat.components import Component
 from . import resources
 
 from zygoat.utils.files import use_dir
-from zygoat.constants import Projects, Phases
+from zygoat.constants import Projects
 
 from .docker_compose import docker_compose
 
@@ -21,9 +21,6 @@ class Dockerfile(Component):
             with open(file_name, "w") as f:
                 f.write(importlib.resources.read_text(resources, file_name))
 
-    def update(self):
-        self.call_phase(Phases.CREATE, force_create=True)
-
     def delete(self):
         with use_dir(Projects.BACKEND):
             log.info(f"Deleting {file_name}")
